@@ -30,7 +30,8 @@ mod blob {
                         .max_concurrency(n_concurrency);
                     let condow = Condow::new(client.clone(), config).unwrap();
 
-                    let downloader = condow.downloader_with_reporting(SimpleReporterFactory);
+                    let downloader =
+                        condow.downloader_with_reporting(SimpleReporterFactory::default());
 
                     let result_stream = downloader.download_rep(NoLocation, ..).await.unwrap();
 
@@ -65,7 +66,8 @@ mod blob {
                         .max_concurrency(n_concurrency);
                     let condow = Condow::new(client.clone(), config).unwrap();
 
-                    let downloader = condow.downloader_with_reporting(SimpleReporterFactory);
+                    let downloader =
+                        condow.downloader_with_reporting(SimpleReporterFactory::default());
 
                     let result_stream = downloader.download_rep(NoLocation, ..).await.unwrap();
 
@@ -111,7 +113,7 @@ mod range {
                         for from_idx in [0usize, 101, 255, 256] {
                             let range = from_idx..;
 
-                            let result_stream = machinery::start_download(
+                            let result_stream = machinery::download(
                                 &condow,
                                 NoLocation,
                                 range.clone(),
@@ -157,7 +159,7 @@ mod range {
                         for from_idx in [0usize, 101, 255, 256] {
                             let range = from_idx..;
 
-                            let result_stream = machinery::start_download(
+                            let result_stream = machinery::download(
                                 &condow,
                                 NoLocation,
                                 range.clone(),
@@ -212,7 +214,7 @@ mod range {
                             let range = 0..=end_incl;
                             let expected_range_end = (end_incl + 1).min(data.len());
 
-                            let result_stream = machinery::start_download(
+                            let result_stream = machinery::download(
                                 &condow,
                                 NoLocation,
                                 range.clone(),
@@ -258,7 +260,7 @@ mod range {
                             let range = 0..end_excl;
                             let expected_range_end = end_excl.min(data.len());
 
-                            let result_stream = machinery::start_download(
+                            let result_stream = machinery::download(
                                 &condow,
                                 NoLocation,
                                 range.clone(),
@@ -312,7 +314,7 @@ mod range {
                                     let range = 0..=end_incl;
                                     let expected_range_end = (end_incl + 1).min(data.len());
 
-                                    let result_stream = machinery::start_download(
+                                    let result_stream = machinery::download(
                                         &condow,
                                         NoLocation,
                                         range,
@@ -359,7 +361,7 @@ mod range {
                                     let range = 0..end_excl;
                                     let expected_range_end = end_excl.min(data.len());
 
-                                    let result_stream = machinery::start_download(
+                                    let result_stream = machinery::download(
                                         &condow,
                                         NoLocation,
                                         range,
@@ -416,7 +418,7 @@ mod range {
                                         let range = start..=(end_incl);
                                         let expected_range_end = (end_incl + 1).min(data.len());
 
-                                        let result_stream = machinery::start_download(
+                                        let result_stream = machinery::download(
                                             &condow,
                                             NoLocation,
                                             range,
@@ -466,7 +468,7 @@ mod range {
                                         let range = start..(end_excl);
                                         let expected_range_end = end_excl.min(data.len());
 
-                                        let result_stream = machinery::start_download(
+                                        let result_stream = machinery::download(
                                             &condow,
                                             NoLocation,
                                             range,
